<?php
namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request;
use Teknisa\MAN\Services;
use Teknisa\MAN\Utilities;

class RelProdutividadeOperador  {

    protected $RelProdOperService;
    protected $utilService;

    public function __construct(Services\RelProdOperService $RelProdOperService, Utilities\Util $utilService) {
        $this->RelProdOperService = $RelProdOperService;
        $this->utilService = $utilService;
    }

    public function find(DTO\Request\Filter $request, DTO\Response $response) {

        $result = [];
        $conditions = $this->utilService->getParamsAsArray($request);
        
        if(isset($conditions['CDFILIAL']) && !empty($conditions['CDFILIAL'])) {
        $conditions = $this->buildParamsFaturamento($conditions);
        $result = $this->RelProdOperService->findProdOpe($conditions['CDFILIAL'], $conditions['DTENTRVENDAINI'], $conditions['DTENTRVENDAFIN'], $conditions['CDCAIXA'], $conditions['NRORG'], $conditions['TCDCAIXA'], $conditions['CDOPERADOR'], $conditions['TCDOPERADOR'], $conditions['MODALIDADE'], $conditions['TMODALIDADE']);

        $response->addDataSet(new DataSet("vnd55019_relProdutividadeOperador", $result));
        }
        return $response;
    }

    public function buildParamsFaturamento($conditions){
        $conditions['CDFILIAL'] = implode('_', $conditions['CDFILIAL']);

        if(array_key_exists('DTENTRVENDA', $conditions)) {
            $conditions['DTENTRVENDAINI'] = $conditions['DTENTRVENDA'][0];
            $conditions['DTENTRVENDAFIN'] = $conditions['DTENTRVENDA'][1];
            unset($conditions['DTENTRVENDA']);
        }

        if(array_key_exists('MODALIDADE', $conditions)) {
        $conditions['MODALIDADE'] = implode('_', $conditions['MODALIDADE']);
        $conditions['TMODALIDADE'] = '';
        } else {
        $conditions['TMODALIDADE'] = 'T';
        $conditions['MODALIDADE'] = '';
        }

        if (isset($conditions['CDOPERADOR'])){
            if(is_array($conditions['CDOPERADOR'])){
                $conditions['CDOPERADOR'] = implode('_', $conditions['CDOPERADOR']);
                $conditions['TCDOPERADOR'] = 'E';
            }
            else{
                $conditions['CDOPERADOR'] = null;
                $conditions['TCDOPERADOR'] = 'T';
            }
        }else{
            $conditions['CDOPERADOR'] = null;
            $conditions['TCDOPERADOR'] = 'T';
        }

        if (isset($conditions['CDCAIXA'])){
            if(is_array($conditions['CDCAIXA'])){
                $conditions['CDCAIXA'] = implode('_', $conditions['CDCAIXA']);
                $conditions['TCDCAIXA'] = 'E';
            }
            else{
                $conditions['CDCAIXA'] = null;
                $conditions['TCDCAIXA'] = 'T';
            }
        }else{
            $conditions['CDCAIXA'] = null;
            $conditions['TCDCAIXA'] = 'T';
        }
        return $conditions;
    }
}